####
jusolink.py
####
jusoink 1.0.2

주소링크 API for Python.

* requirements
 
  * Python 2.6+
  * linkhub

************
Installation
************

Install via pip:

::

    $ pip install jusolink

Install from source:

::

    $ git clone git://github.com/linkhub-sdk/jusolink.py.git
    $ cd jusolink.py
    $ python setup.py install
